@@ -1,17 +1,17 @@
 ;;; utils.scm: common utility procedures
-;;; Copyright (c) 2005, 2006, 2007 Freetalk Core Team 
+;;; Copyright (c) 2005-2014 Freetalk Core Team
 ;;; This file is part of GNU Freetalk.
-;;; 
+;;;
 ;;; Freetalk is free software; you can redistribute it and/or modify it
 ;;; under the terms of the GNU General Public License as published by
 ;;; the Free Software Foundation; either version 3 of the License, or
 ;;; (at your option) any later version.
-;;; 
+;;;
 ;;; Freetalk is distributed in the hope that it will be useful, but
 ;;; WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ;;; General Public License for more details.
-;;; 
+;;;
 ;;; You should have received a copy of the GNU General Public License
 ;;; along with this program.  If not, see
 ;;; <http://www.gnu.org/licenses/>.
@@ -23,10 +23,16 @@
 (define (/version args)
   "display version info"
   (display (string-append (_ "freetalk (FreeTalk) ") (ft-version) "\n"
-			  (_ "Copyright (C) 2005, 2006 FreeTalk Core Team.\n")
-			  (_ "This is free software; see the source for copying conditions.  There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"))))
+                          (_ "Copyright (C) 2005-2014 FreeTalk Core Team.\n")
+                          (_ "This is free software; see the source for copying conditions.\n")
+                          (_ "There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"))))
 
-(add-command! /version "/version" "/version" "display freetalk version information")
+(add-command! /version "version" "/version" "display freetalk version information")
+
+(define (/run-cmd args)
+  "run commands"
+  (ft-run-command args))
+(add-command! /run-cmd "run-cmd" "/run-cmd" "run command provided in args")
 
 ;; range with proper tail recursion --ab
 (define (range start end)
@@ -45,16 +51,16 @@
   (if (number? item)
       (string->symbol (number->string item))
       (if (string? item)
-	  (string->symbol item)
-	  item)))
-  
-(define (list->asv li any) 
+          (string->symbol item)
+          item)))
+
+(define (list->asv li any)
   "convert list to any separated vector"
   (if (=(length li) 1)
       (car li)
       (string-append (car li) any (list->asv (cdr li) any))))
 
-(define (list->csv li) 
+(define (list->csv li)
   "convert list to comma separated vector"
   (list->asv li ", "))
 
@@ -69,27 +75,26 @@
   (if (= (length li) 0)
       '()
       (if (= (length li) 1)
-	  (list 
-	   (symbol->string 
-	    (any->symbol (car li))))
-	  (append (list 
-		   (symbol->string 
-		    (any->symbol (car li))))
-		  (list->strlist (cdr li))))))
+          (list
+           (symbol->string
+            (any->symbol (car li))))
+          (append (list
+                   (symbol->string
+                    (any->symbol (car li))))
+                  (list->strlist (cdr li))))))
 
 (define (send-messages-to-all roster-list message)
   "Send messages to all"
   (for-each (lambda (buddy)
-	      (ft-send-message-no-hook buddy message))
-	    roster-list))
+              (ft-send-message-no-hook buddy message))
+            roster-list))
 
 (define (local-date-time)
   (string-append
                  (strftime "%F" (localtime (current-time)))
-		 " "
+                 " "
                  (strftime "%T" (localtime (current-time)))))
 
-
 (define (skip-comment port)
   (let ((char (peek-char port)))
     (if (or (eof-object? char)
@@ -102,44 +107,44 @@
 (define (skip-whitespace port)
   (let ((char (peek-char port)))
     (cond ((or (eof-object? char)
-	       (char=? #\newline char))
-	   char)
-	  ((char-whitespace? char)
-	   (read-char port)
-	   (skip-whitespace port))
-;;  	  ((char=? #\# char)
-;;  	   (read-char port)
-;;  	   (skip-comment port))
-	  (else char))))
+               (char=? #\newline char))
+           char)
+          ((char-whitespace? char)
+           (read-char port)
+           (skip-whitespace port))
+;;        ((char=? #\# char)
+;;         (read-char port)
+;;         (skip-comment port))
+          (else char))))
 
 (define (read-token port delim)
   (letrec
       ((loop
-	(lambda (chars)
-	  (let ((char (peek-char port)))
-	    (cond ((eof-object? char)
-		   (do-eof char chars))
-		  ((char=? #\newline char)
-		   (do-eot chars))
-		  ((char-whitespace? char)
-		   (do-eot chars))
-;;  		   (let ((terminator (skip-comment port)))
-;;  		     (if (eof-object? char)
-;;  			 (do-eof char chars)
-;;  			 (do-eot chars))))
-		  (else
-		   (read-char port)
-		   (loop (cons char chars)))))))
+        (lambda (chars)
+          (let ((char (peek-char port)))
+            (cond ((eof-object? char)
+                   (do-eof char chars))
+                  ((char=? #\newline char)
+                   (do-eot chars))
+                  ((char-whitespace? char)
+                   (do-eot chars))
+;                  (let ((terminator (skip-comment port)))
+;;                   (if (eof-object? char)
+;;                       (do-eof char chars)
+;;                       (do-eot chars))))
+                  (else
+                   (read-char port)
+                   (loop (cons char chars)))))))
        (do-eof
-	(lambda (eof chars)
-	  (if (null? chars)
-	      eof
-	      (do-eot chars))))
+        (lambda (eof chars)
+          (if (null? chars)
+              eof
+              (do-eot chars))))
        (do-eot
-	(lambda (chars)
-	  (if (null? chars)
-	      #f
-	      (list->string (reverse! chars))))))
+        (lambda (chars)
+          (if (null? chars)
+              #f
+              (list->string (reverse! chars))))))
     (skip-whitespace port)
     (loop '())))
 
@@ -148,25 +153,24 @@
   (with-input-from-string sentence
     (lambda ()
       (letrec
-	  ((next-token
-	    (lambda ()
-	      (read-token (current-input-port) #\#)))
-	   (append-word
-	    (lambda (word-list)
-	      (let
-		  ((word (next-token)))
-		(if (eof-object? word)
-		    word-list
-		    (begin
-		      (append-word 
-		       (append word-list (list word)))))))))
-	(append-word '())))))
+          ((next-token
+            (lambda ()
+              (read-token (current-input-port) #\#)))
+           (append-word
+            (lambda (word-list)
+              (let
+                  ((word (next-token)))
+                (if (eof-object? word)
+                    word-list
+                    (begin
+                      (append-word
+                       (append word-list (list word)))))))))
+        (append-word '())))))
 
 
 (define (blank-line? line)
   "return true if line is blank"
   (null? (sentence->words line)))
-
 
 ;;; string utils
 ;; for string-match procedure
@@ -179,39 +183,38 @@
   (with-input-from-string sentence
     (lambda ()
       (letrec
-	  ((next-token (lambda ()
-			 (read (current-input-port))))
-	   (append-word (lambda (word-list)
-			  (let
-			      ((word (next-token)))
-			    (if (eof-object? word)
-				word-list
-				(begin
-				  (append-word (append word-list 
-						       (list word)))))))))
-	(append-word '())))))
+          ((next-token (lambda ()
+                         (read (current-input-port))))
+           (append-word (lambda (word-list)
+                          (let
+                              ((word (next-token)))
+                            (if (eof-object? word)
+                                word-list
+                                (begin
+                                  (append-word (append word-list
+                                                       (list word)))))))))
+        (append-word '())))))
 
 
 (define (list->sentence li)
   "convert list to space separated sentence"
   (let
       ((word (if (symbol? (car li))
-		 (symbol->string (car li))
-		 (number->string (car li)))))
+                 (symbol->string (car li))
+                 (number->string (car li)))))
     (if (= (length li) 1)
-	word
-	(string-append word " " (list->sentence (cdr li))))))
-
+        word
+        (string-append word " " (list->sentence (cdr li))))))
 
 (define (string-separate str ch)
   (let ((index (string-index str ch)))
     (if index
-	(cons (substring str 0 index)
-	      (string-separate (substring str 
-				       (+ index 1) 
-				       (string-length str)) 
-			    ch))
-	(list str))))
+        (cons (substring str 0 index)
+              (string-separate (substring str
+                                          (+ index 1)
+                                          (string-length str))
+                               ch))
+        (list str))))
 
 
 (define (blank-line? line)
@@ -222,7 +225,7 @@
 
 (define (dollor->number dollor)
   "convert dollor symbol to number"
-  (string->number 
+  (string->number
    (cadr (string-separate (symbol->string dollor) #\$))))
 
 
@@ -230,10 +233,10 @@
   "skip blank lines and read the next line"
   (let ((line (read-line fport)))
     (if (eof-object? line)
-	""
-	(if (not (blank-line? line))
-	    line
-	    (read-next-line fport)))))
+        ""
+        (if (not (blank-line? line))
+            line
+            (read-next-line fport)))))
 
 
 (define (string-string? str find-string)
@@ -243,11 +246,11 @@
 
 (define (date->list date)
   "convert flat yymmdd num to (yy mm dd) list"
-  (let* 
-      ((date-str (list->string 
-		  (map (lambda (c) 
-			 (if (eq? c #\space) #\0 c))
-		       (string->list (format #f "~6d" date)))))
+  (let*
+      ((date-str (list->string
+                  (map (lambda (c)
+                         (if (eq? c #\space) #\0 c))
+                       (string->list (format #f "~6d" date)))))
        (yy (substring date-str 0 2))
        (mm (substring date-str 2 4))
        (dd (substring date-str 4 6)))
