@@ -1,17 +1,17 @@
 /*
-  Copyright (c) 2005, 2006, 2007 Freetalk Core Team
+  Copyright (c) 2005-2014 Freetalk Core Team
   This file is part of Freetalk.
-  
+
   Freetalk is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published
   by the Free Software Foundation; either version 3 of the License,
   or (at your option) any later version.
-  
+
   Freetalk is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see
   <http://www.gnu.org/licenses/>.
@@ -20,16 +20,20 @@
 #ifndef __PRESENCE_H__
 #define __PRESENCE_H__
 
+#ifndef _CONFIG_H
+#define _CONFIG_H
+#include "config.h"
+#endif
 
 void ft_presence_cb (LmMessage *msg);
 void ft_presence_send_final (void);
 void ft_presence_send_initial (void);
 
 typedef enum {
-  SUBSCRIBE,
-  SUBSCRIBED,
-  UNSUBSCRIBE,
-  UNSUBSCRIBED
+        SUBSCRIBE,
+        SUBSCRIBED,
+        UNSUBSCRIBE,
+        UNSUBSCRIBED
 } FtPresenceMsgType;
 
 void ft_presence_subscription_allow (char *jid);
